==> AsposeCellsCloud-CellsApi-25.2.tar.gz: AsposeCellsCloud-CellsApi-25.2/lib/AsposeCellsCloud/Object/TrimContentOptions.pm <==
=begin comment

Copyright (c) 2025 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::TrimContentOptions;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::DataSource;
use AsposeCellsCloud::Object::FileInfo;
use AsposeCellsCloud::Object::ScopeOptions; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => 'I`m sorry, but you haven`t provided any specific content for me to summarize. Please provide the features you would like to be summarized.            ',
                                  class => 'TrimContentOptions',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'data_source' => {
     	datatype => 'DataSource',
     	base_name => 'DataSource',
     	description => 'This class has a public property named DataSource of type DataSource that has both a getter and a setter method.            ',
     	format => '',
     	read_only => '',
     		},
     'file_info' => {
     	datatype => 'FileInfo',
     	base_name => 'FileInfo',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'trim_content' => {
     	datatype => 'string',
     	base_name => 'TrimContent',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'trim_leading' => {
     	datatype => 'boolean',
     	base_name => 'TrimLeading',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'trim_trailing' => {
     	datatype => 'boolean',
     	base_name => 'TrimTrailing',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'trim_space_between_word_to1' => {
     	datatype => 'boolean',
     	base_name => 'TrimSpaceBetweenWordTo1',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'trim_non_breaking_spaces' => {
     	datatype => 'boolean',
     	base_name => 'TrimNonBreakingSpaces',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'remove_extra_line_breaks' => {
     	datatype => 'boolean',
     	base_name => 'RemoveExtraLineBreaks',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'remove_all_line_breaks' => {
     	datatype => 'boolean',
     	base_name => 'RemoveAllLineBreaks',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'scope_options' => {
     	datatype => 'ScopeOptions',
     	base_name => 'ScopeOptions',
     	description => '',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'data_source' => 'DataSource',
    'file_info' => 'FileInfo',
    'trim_content' => 'string',
    'trim_leading' => 'boolean',
    'trim_trailing' => 'boolean',
    'trim_space_between_word_to1' => 'boolean',
    'trim_non_breaking_spaces' => 'boolean',
    'remove_extra_line_breaks' => 'boolean',
    'remove_all_line_breaks' => 'boolean',
    'scope_options' => 'ScopeOptions' 
} );

__PACKAGE__->attribute_map( {
    'data_source' => 'DataSource',
    'file_info' => 'FileInfo',
    'trim_content' => 'TrimContent',
    'trim_leading' => 'TrimLeading',
    'trim_trailing' => 'TrimTrailing',
    'trim_space_between_word_to1' => 'TrimSpaceBetweenWordTo1',
    'trim_non_breaking_spaces' => 'TrimNonBreakingSpaces',
    'remove_extra_line_breaks' => 'RemoveExtraLineBreaks',
    'remove_all_line_breaks' => 'RemoveAllLineBreaks',
    'scope_options' => 'ScopeOptions' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/lib/AsposeCellsCloud/Object/TrimContentOptions.pm <==
=begin comment

Copyright (c) 2025 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::TrimContentOptions;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::DataSource;
use AsposeCellsCloud::Object::FileInfo;
use AsposeCellsCloud::Object::ScopeOptions; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'TrimContentOptions',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'data_source' => {
     	datatype => 'DataSource',
     	base_name => 'DataSource',
     	description => 'Represents data source.  There are three types of data, they are CloudFileSystem, RequestFiles, HttpUri.',
     	format => '',
     	read_only => '',
     		},
     'file_info' => {
     	datatype => 'FileInfo',
     	base_name => 'FileInfo',
     	description => 'Represents file information. Include of filename, filesize, and file content(base64String).',
     	format => '',
     	read_only => '',
     		},
     'trim_content' => {
     	datatype => 'string',
     	base_name => 'TrimContent',
     	description => 'Trim Content',
     	format => '',
     	read_only => '',
     		},
     'trim_leading' => {
     	datatype => 'boolean',
     	base_name => 'TrimLeading',
     	description => 'If the trim leading value is true, the trim content before and after cell values will be deleted.',
     	format => '',
     	read_only => '',
     		},
     'trim_trailing' => {
     	datatype => 'boolean',
     	base_name => 'TrimTrailing',
     	description => 'If the trim trailing value is true, the trim content before and after cell values will be deleted.',
     	format => '',
     	read_only => '',
     		},
     'trim_space_between_word_to1' => {
     	datatype => 'boolean',
     	base_name => 'TrimSpaceBetweenWordTo1',
     	description => 'When the trim space between word to 1 parameter is true, it enables the removal of extra spaces between words within a cell, ensuring that only a single space is maintained between words.',
     	format => '',
     	read_only => '',
     		},
     'trim_non_breaking_spaces' => {
     	datatype => 'boolean',
     	base_name => 'TrimNonBreakingSpaces',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'remove_extra_line_breaks' => {
     	datatype => 'boolean',
     	base_name => 'RemoveExtraLineBreaks',
     	description => 'When this parameter is enabled (set to True), it deletes extra line breaks within the selected range, ensuring that only necessary line breaks are retained.',
     	format => '',
     	read_only => '',
     		},
     'remove_all_line_breaks' => {
     	datatype => 'boolean',
     	base_name => 'RemoveAllLineBreaks',
     	description => 'When this parameter is enabled (set to True), it removes all line breaks within the selected range, resulting in a continuous block of text without any line breaks.',
     	format => '',
     	read_only => '',
     		},
     'scope_options' => {
     	datatype => 'ScopeOptions',
     	base_name => 'ScopeOptions',
     	description => 'Specifies the range of cells within the worksheet where the spreadsheet operations will be performed. This parameter allows users to define the exact area to be processed, ensuring that operations are applied only to the designated cells.',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'data_source' => 'DataSource',
    'file_info' => 'FileInfo',
    'trim_content' => 'string',
    'trim_leading' => 'boolean',
    'trim_trailing' => 'boolean',
    'trim_space_between_word_to1' => 'boolean',
    'trim_non_breaking_spaces' => 'boolean',
    'remove_extra_line_breaks' => 'boolean',
    'remove_all_line_breaks' => 'boolean',
    'scope_options' => 'ScopeOptions' 
} );

__PACKAGE__->attribute_map( {
    'data_source' => 'DataSource',
    'file_info' => 'FileInfo',
    'trim_content' => 'TrimContent',
    'trim_leading' => 'TrimLeading',
    'trim_trailing' => 'TrimTrailing',
    'trim_space_between_word_to1' => 'TrimSpaceBetweenWordTo1',
    'trim_non_breaking_spaces' => 'TrimNonBreakingSpaces',
    'remove_extra_line_breaks' => 'RemoveExtraLineBreaks',
    'remove_all_line_breaks' => 'RemoveAllLineBreaks',
    'scope_options' => 'ScopeOptions' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
